package WWW::Connpass::Event::Question::CheckBox;
use strict;
use warnings;

use parent qw/WWW::Connpass::Event::Question/;

sub _answer_type { 2 }

1;
__END__

=pod

=encoding utf-8

=head1 NAME

WWW::Connpass::Event::Question::CheckBox - TODO

=head1 SYNOPSIS

    use WWW::Connpass::Event::Question::CheckBox;

=head1 DESCRIPTION

TODO

=head1 SEE ALSO

L<perl>

=head1 LICENSE

Copyright (C) karupanerura.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=head1 AUTHOR

karupanerura E<lt>karupa@cpan.orgE<gt>

=cut
